'\" 
'\" $Header: /home/neil/src/tcl/tensor/doc/RCS/tensorexpr.n,v 1.1 2008/07/19 20:25:48 neil Exp $
'\" 
.so man.macros
.HS tensorexpr tcl
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
tensor::expr \- Evaluate a tensor expression
.SH SYNOPSIS
.sp
\fBpackage require Tensor\fR
.sp
\fBtensor::expr \fI tensorExpr\fR
.BE

.SH DESCRIPTION
.PP
The \fB tensor::expr\fI command evaluates its argument as a sequence
of tensor assignments. The arguments may contain multiple assignments
separated by semicolons. Each assignment takes the form
.DS
\fI tensorSection assignOp tensorExpression\fR
.DE
where \fItensorSection\fR describes part of a tensor whose contents
will be changed, \fIassignOp\fR is one of \fB=\fR, \fB+=\fR,
\fB-=\fR, \fB*=\fR, or \fB/=\fR, and \fItensorExpression\fR is
a tensor expression.
.PP
Tensor expressions can be thought of as a generalization of matrix
expressions to higher-dimensional arrays of numbers. A tensor of order 1
is a vector, and a tensor of order 2 is a matrix, but tensors of order
3 or more are possible, and have no real analogue in matrix notation.
.PP
A tensor expression consists of a sum/difference of terms, where each
term consistes of the product or quotient of factors. Factors, in turn,
can be scalars, tensors, a unary minus followed by a factor, or
a parenthesized subexpression. Every tensor section is followed by
a parenthesized list of dummy index variables. If an index variable
is repeated within a term, then the term is summed with respect
to that variable. For example, the tensor assignment
.RS
    y(i) = A(i,j)*x(j)
.RE
is a matrix-by-vector multiply, giving a vector result. Since the dummy
variable \fBj\fR is repeated, summation occurs with respect to that
variable. (The three tensors A, x, and y must exist, and their dimensions
must be appropriate.) Likewise,
.RS
    y(i) = A(j,i)*x(j)
.RE
(note the reversal of A's subscripts) is the product of the \fItranspose\fR
of A with vector x. Generalizing to hiegher-order tensors, the assignment
.RS
    v(i,j) = A(i,j,k)*w(k)
.RE
is equvalent to multiplying a vector of matrices by a vector, giving
a vector of vectors (which is essentially a matrix.)
.PP
It is also possible to use subsets of tensors in computations and
assignments. For example, we may use expressions like
.RS
    y(i=0:end:2) = x(i=1:end:2)
.RE
to assign elements 1, 3, 5, etc. of vector x to the 0, 2, 4, etc elements
of vector y. By default, dummy indices run over the entire range of the
tensor's index, but by appending an \fB=\fR sign and a range, or set
of ranges, that can be changed. Ranges may be simple, in which case
they take the form
.DS
    \fIstart?\fB:\fIend??\fB:\fIstep\fR
.DE
where \fIend\fR defaults to the start value, and \fIstep\fR, which may
be negative, defaults to 1. (NOTE: the \fIstart\fR element is ALWAYS
included in the range, regardless of the values of \fIend\fR and \fIstep\fR,
so all ranges have at least one index value.) Compound ranges consist of
one or more simple ranges enclosed in parentheses and separated by
commas:
.DS
    \fIcompoundRange ==> \fB(\fIr1\fB,\fIr2 ...\fB)\fR
.DE
So for example, if x is a vector that's twice as long as y, we could write
.RS
    x(i) = y(i=(0:end,0:end))
.RE
in order to concatenate y with itself and assign that value to x.

.SH AUTHOR
Neil McKay, mckay@eecs.umich.edu

.SH "SEE ALSO"
tensor(n)

